Ueberauth.Strategy.SlackV2.OAuth (Ueberauth Slack V2 v1.0.0) View Source
An implementation of OAuth2 for Slack OAuth V2 API.
To add your client_id and client_secret include these values in your configuration.
config :ueberauth, Ueberauth.Strategy.SlackV2.OAuth,
client_id: System.get_env("SLACK_CLIENT_ID"),
client_secret: System.get_env("SLACK_CLIENT_SECRET")The JSON serializer used is the same as Ueberauth so if you need to
customize it, you can configure it in the Ueberauth configuration:
config :ueberauth, Ueberauth,
json_library: Poison # Defaults to Jason
Link to this section Summary
Functions
Callback implementation for OAuth2.Strategy.authorize_url/2.
Callback implementation for OAuth2.Strategy.get_token/3.
Link to this section Functions
Callback implementation for OAuth2.Strategy.authorize_url/2.
Callback implementation for OAuth2.Strategy.get_token/3.